@@ -1,3 +1,4 @@
+from __future__ import with_statement
 import os
 import shutil
 import tempfile
@@ -13,7 +14,7 @@ from weblog.template import environment
 from weblog.publish import load_post_list
 from weblog.date import command_date
 from weblog.publish import command_publish
-from weblog.load import load_configuration, ConfigurationError
+from weblog import configuration
 
 def _file(string):
     return StringIO(dedent(string))
@@ -202,7 +203,7 @@ class TestGeneration(unittest.TestCase):
                                                       dirname(__file__),
                                                       'test', dirname),
                               output_dir=self.tempdir,
-                              configuration_file='weblog.ini',
+                              configuration_file='config.py',
                               debug=False))
         command_publish(None, options)
 
@@ -221,114 +222,26 @@ class TestGeneration(unittest.TestCase):
 
 class TestConfiguration(unittest.TestCase):
 
+    @staticmethod
+    def __config(string=None):
+        f = tempfile.NamedTemporaryFile()
+        if string:
+            f.write(string)
+            f.seek(0)
+        return f
+
     def test_empty(self):
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(''))
+        with self.__config() as f:
+            self.assertEqual(configuration.read(f.name), dict())
 
     def test_bad_encoding(self):
-        conf = '''\
-        [weblog]
-        title=test
-        author=Henry Pr\xc3\xaacheur <henry@precheur.org>
-        url=http://example.com/'''
-        # Default encoding is ascii
-
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(conf))
+        with self.__config("encoding = 'DOES NOT EXIST'") as f:
+            self.assertRaises(LookupError, configuration.read, f.name)
 
     def test_encoding(self):
-        conf = u'''\
-        [weblog]
-        title=test
-        author=Henry Pr\xeacheur <henry@precheur.org>
-        encoding=utf8
-        url=http://example.com/'''.encode('utf8')
-        d = load_configuration(_file(conf))
-        self.assertEqual(d['author'],
-                         u'Henry Pr\xeacheur <henry@precheur.org>')
-
-    def test_load_simple(self):
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog'''
-        self.assertEqual(load_configuration(_file(sample_configuration)),
-                         dict(title=u'Test title',
-                              url=u'http://example.com/',
-                              feed_limit=10,
-                              description=u'Example blog',
-                              post_per_page=10))
-
-    def test_load_no_title(self):
-        sample_configuration = '''\
-        [weblog]
-        url = http://example.com
-        description = Example blog'''
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(sample_configuration))
-
-    def test_load_no_title(self):
-        sample_configuration = '''\
-        [weblog]
-        title = dummy title
-        description = Example blog'''
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(sample_configuration))
-
-    def test_load_feed_limit(self):
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog'''
-        c = load_configuration(_file(sample_configuration))
-        self.assertEqual(c['feed_limit'], 10)
-
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog
-        feed_limit = 42'''
-        c = load_configuration(_file(sample_configuration))
-        self.assertEqual(c['feed_limit'], 42)
-
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog
-        feed_limit = not_a_number'''
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(sample_configuration))
-
-    def test_load_post_per_page(self):
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog'''
-        c = load_configuration(_file(sample_configuration))
-        self.assertEqual(c['post_per_page'], 10)
-
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog
-        post_per_page = 42'''
-        c = load_configuration(_file(sample_configuration))
-        self.assertEqual(c['post_per_page'], 42)
-
-        sample_configuration = '''\
-        [weblog]
-        title = Test title
-        url = http://example.com
-        description = Example blog
-        post_per_page = not_a_number'''
-        self.assertRaises(ConfigurationError,
-                          load_configuration, _file(sample_configuration))
+        with self.__config("encoding = 'latin-1'") as f:
+            self.assertEqual(configuration.read(f.name),
+                             dict(encoding='latin-1'))
 
 if __name__ == '__main__':
     import nose
