@@ -1,5 +1,5 @@
 __author__ = u'Henry Pr\u00EAcheur <henry@precheur.org>'
-__version__ = '1.3'
+__version__ = '2.0'
 __license__ = 'ISCL'
 
 def main():
@@ -29,7 +29,7 @@ def main():
                       'is searched.'
                       ' [default: \'%default\']',
                       metavar='FILE',
-                      default='weblog.ini')
+                      default='config.py')
     parser.add_option('-q', '--quiet',
                       dest='quiet', default=False, action='store_true',
                       help='Do not output anything except critical error '
